# Py-Git-GhCli

Bunch of Python functions for Git and GitHub CLI tasks.


## Install

```shell
pip install pyggc
```


## Usage

```python
from pyggc.ghcli import get_stargazers
from pyggc.git import get_num_commits

```


## License

The scripts and documentation in this project are released under the MIT License.